/****************************************************************************
** Meta object code from reading C++ file 'activities_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "activities_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'activities_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN40OrgKdeActivityManagerActivitiesInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeActivityManagerActivitiesInterface::qt_create_metaobjectdata<qt_meta_tag_ZN40OrgKdeActivityManagerActivitiesInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeActivityManagerActivitiesInterface",
        "ActivityAdded",
        "",
        "activity",
        "ActivityChanged",
        "ActivityDescriptionChanged",
        "description",
        "ActivityIconChanged",
        "icon",
        "ActivityNameChanged",
        "name",
        "ActivityRemoved",
        "ActivityStarted",
        "ActivityStateChanged",
        "state",
        "ActivityStopped",
        "CurrentActivityChanged",
        "ActivityDescription",
        "QDBusPendingReply<QString>",
        "ActivityIcon",
        "ActivityInformation",
        "QDBusPendingReply<ActivityInfo>",
        "ActivityName",
        "ActivityState",
        "QDBusPendingReply<int>",
        "AddActivity",
        "CurrentActivity",
        "ListActivities",
        "QDBusPendingReply<QStringList>",
        "ListActivitiesWithInformation",
        "QDBusPendingReply<ActivityInfoList>",
        "RemoveActivity",
        "QDBusPendingReply<>",
        "SetActivityDescription",
        "SetActivityIcon",
        "SetActivityName",
        "SetCurrentActivity",
        "QDBusPendingReply<bool>",
        "StartActivity",
        "StopActivity"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActivityAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ActivityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ActivityDescriptionChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'ActivityIconChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 8 },
        }}),
        // Signal 'ActivityNameChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'ActivityRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ActivityStarted'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ActivityStateChanged'
        QtMocHelpers::SignalData<void(const QString &, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 14 },
        }}),
        // Signal 'ActivityStopped'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'CurrentActivityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ActivityDescription'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ActivityIcon'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(19, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ActivityInformation'
        QtMocHelpers::SlotData<QDBusPendingReply<ActivityInfo>(const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ActivityName'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'ActivityState'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(const QString &)>(23, 2, QMC::AccessPublic, 0x80000000 | 24, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'AddActivity'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QString &)>(25, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'CurrentActivity'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(26, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'ListActivities'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(int)>(27, 2, QMC::AccessPublic, 0x80000000 | 28, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'ListActivities'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(27, 2, QMC::AccessPublic, 0x80000000 | 28),
        // Slot 'ListActivitiesWithInformation'
        QtMocHelpers::SlotData<QDBusPendingReply<ActivityInfoList>()>(29, 2, QMC::AccessPublic, 0x80000000 | 30),
        // Slot 'RemoveActivity'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(31, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetActivityDescription'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(33, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'SetActivityIcon'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(34, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 8 },
        }}),
        // Slot 'SetActivityName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(35, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'SetCurrentActivity'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(36, 2, QMC::AccessPublic, 0x80000000 | 37, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'StartActivity'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(38, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'StopActivity'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(39, 2, QMC::AccessPublic, 0x80000000 | 32, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeActivityManagerActivitiesInterface, qt_meta_tag_ZN40OrgKdeActivityManagerActivitiesInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeActivityManagerActivitiesInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40OrgKdeActivityManagerActivitiesInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40OrgKdeActivityManagerActivitiesInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN40OrgKdeActivityManagerActivitiesInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeActivityManagerActivitiesInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeActivityManagerActivitiesInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActivityAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->ActivityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->ActivityDescriptionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->ActivityIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->ActivityNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->ActivityRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->ActivityStarted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->ActivityStateChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->ActivityStopped((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->CurrentActivityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: { QDBusPendingReply<QString> _r = _t->ActivityDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<QString> _r = _t->ActivityIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<ActivityInfo> _r = _t->ActivityInformation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<ActivityInfo>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<QString> _r = _t->ActivityName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<int> _r = _t->ActivityState((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<QString> _r = _t->AddActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<QString> _r = _t->CurrentActivity();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QStringList> _r = _t->ListActivities((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<QStringList> _r = _t->ListActivities();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<ActivityInfoList> _r = _t->ListActivitiesWithInformation();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<ActivityInfoList>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<> _r = _t->RemoveActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->SetActivityDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->SetActivityIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<> _r = _t->SetActivityName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<bool> _r = _t->SetCurrentActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->StartActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->StopActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerActivitiesInterface::*)(const QString & )>(_a, &OrgKdeActivityManagerActivitiesInterface::ActivityAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerActivitiesInterface::*)(const QString & )>(_a, &OrgKdeActivityManagerActivitiesInterface::ActivityChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerActivitiesInterface::*)(const QString & , const QString & )>(_a, &OrgKdeActivityManagerActivitiesInterface::ActivityDescriptionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerActivitiesInterface::*)(const QString & , const QString & )>(_a, &OrgKdeActivityManagerActivitiesInterface::ActivityIconChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerActivitiesInterface::*)(const QString & , const QString & )>(_a, &OrgKdeActivityManagerActivitiesInterface::ActivityNameChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerActivitiesInterface::*)(const QString & )>(_a, &OrgKdeActivityManagerActivitiesInterface::ActivityRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerActivitiesInterface::*)(const QString & )>(_a, &OrgKdeActivityManagerActivitiesInterface::ActivityStarted, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerActivitiesInterface::*)(const QString & , int )>(_a, &OrgKdeActivityManagerActivitiesInterface::ActivityStateChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerActivitiesInterface::*)(const QString & )>(_a, &OrgKdeActivityManagerActivitiesInterface::ActivityStopped, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeActivityManagerActivitiesInterface::*)(const QString & )>(_a, &OrgKdeActivityManagerActivitiesInterface::CurrentActivityChanged, 9))
            return;
    }
}

const QMetaObject *OrgKdeActivityManagerActivitiesInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeActivityManagerActivitiesInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN40OrgKdeActivityManagerActivitiesInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeActivityManagerActivitiesInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeActivityManagerActivitiesInterface::ActivityAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgKdeActivityManagerActivitiesInterface::ActivityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OrgKdeActivityManagerActivitiesInterface::ActivityDescriptionChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void OrgKdeActivityManagerActivitiesInterface::ActivityIconChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void OrgKdeActivityManagerActivitiesInterface::ActivityNameChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void OrgKdeActivityManagerActivitiesInterface::ActivityRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void OrgKdeActivityManagerActivitiesInterface::ActivityStarted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void OrgKdeActivityManagerActivitiesInterface::ActivityStateChanged(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void OrgKdeActivityManagerActivitiesInterface::ActivityStopped(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void OrgKdeActivityManagerActivitiesInterface::CurrentActivityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
