/****************************************************************************
** Meta object code from reading C++ file 'activitiescache_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-activities-6.7.0/src/lib/activitiescache_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'activitiescache_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KActivities15ActivitiesCacheE_t {};
} // unnamed namespace

template <> constexpr inline auto KActivities::ActivitiesCache::qt_create_metaobjectdata<qt_meta_tag_ZN11KActivities15ActivitiesCacheE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KActivities::ActivitiesCache",
        "activityAdded",
        "",
        "id",
        "activityChanged",
        "activityRemoved",
        "activityNameChanged",
        "name",
        "activityDescriptionChanged",
        "description",
        "activityIconChanged",
        "icon",
        "currentActivityChanged",
        "serviceStatusChanged",
        "Consumer::ServiceStatus",
        "status",
        "activityListChanged",
        "updateAllActivities",
        "loadOfflineDefaults",
        "updateActivity",
        "removeActivity",
        "setActivityInfoFromReply",
        "QDBusPendingCallWatcher*",
        "watcher",
        "setAllActivitiesFromReply",
        "setCurrentActivityFromReply",
        "setActivityName",
        "setActivityDescription",
        "setActivityIcon",
        "setActivityInfo",
        "ActivityInfo",
        "info",
        "setAllActivities",
        "ActivityInfoList",
        "activities",
        "setCurrentActivity",
        "activity",
        "setServiceStatus",
        "Manager::ServiceStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activityAdded'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'activityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'activityRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'activityNameChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'activityDescriptionChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'activityIconChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'currentActivityChanged'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'serviceStatusChanged'
        QtMocHelpers::SignalData<void(Consumer::ServiceStatus)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'activityListChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAllActivities'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadOfflineDefaults'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateActivity'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'removeActivity'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setActivityInfoFromReply'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'setAllActivitiesFromReply'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'setCurrentActivityFromReply'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'setActivityName'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'setActivityDescription'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'setActivityIcon'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 11 },
        }}),
        // Slot 'setActivityInfo'
        QtMocHelpers::SlotData<void(const ActivityInfo &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setAllActivities'
        QtMocHelpers::SlotData<void(const ActivityInfoList &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'setCurrentActivity'
        QtMocHelpers::SlotData<void(const QString &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'setServiceStatus'
        QtMocHelpers::SlotData<void(Manager::ServiceStatus)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 38, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ActivitiesCache, qt_meta_tag_ZN11KActivities15ActivitiesCacheE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KActivities::ActivitiesCache::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KActivities15ActivitiesCacheE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KActivities15ActivitiesCacheE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KActivities15ActivitiesCacheE_t>.metaTypes,
    nullptr
} };

void KActivities::ActivitiesCache::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActivitiesCache *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activityAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->activityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->activityRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->activityNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->activityDescriptionChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->activityIconChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->currentActivityChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->serviceStatusChanged((*reinterpret_cast<std::add_pointer_t<Consumer::ServiceStatus>>(_a[1]))); break;
        case 8: _t->activityListChanged(); break;
        case 9: _t->updateAllActivities(); break;
        case 10: _t->loadOfflineDefaults(); break;
        case 11: _t->updateActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->removeActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->setActivityInfoFromReply((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 14: _t->setAllActivitiesFromReply((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 15: _t->setCurrentActivityFromReply((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 16: _t->setActivityName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->setActivityDescription((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->setActivityIcon((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 19: _t->setActivityInfo((*reinterpret_cast<std::add_pointer_t<ActivityInfo>>(_a[1]))); break;
        case 20: _t->setAllActivities((*reinterpret_cast<std::add_pointer_t<ActivityInfoList>>(_a[1]))); break;
        case 21: _t->setCurrentActivity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->setServiceStatus((*reinterpret_cast<std::add_pointer_t<Manager::ServiceStatus>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ActivityInfo >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ActivityInfoList >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ActivitiesCache::*)(const QString & )>(_a, &ActivitiesCache::activityAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesCache::*)(const QString & )>(_a, &ActivitiesCache::activityChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesCache::*)(const QString & )>(_a, &ActivitiesCache::activityRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesCache::*)(const QString & , const QString & )>(_a, &ActivitiesCache::activityNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesCache::*)(const QString & , const QString & )>(_a, &ActivitiesCache::activityDescriptionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesCache::*)(const QString & , const QString & )>(_a, &ActivitiesCache::activityIconChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesCache::*)(const QString & )>(_a, &ActivitiesCache::currentActivityChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesCache::*)(Consumer::ServiceStatus )>(_a, &ActivitiesCache::serviceStatusChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ActivitiesCache::*)()>(_a, &ActivitiesCache::activityListChanged, 8))
            return;
    }
}

const QMetaObject *KActivities::ActivitiesCache::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KActivities::ActivitiesCache::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KActivities15ActivitiesCacheE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KActivities::ActivitiesCache::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void KActivities::ActivitiesCache::activityAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KActivities::ActivitiesCache::activityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KActivities::ActivitiesCache::activityRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KActivities::ActivitiesCache::activityNameChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KActivities::ActivitiesCache::activityDescriptionChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KActivities::ActivitiesCache::activityIconChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KActivities::ActivitiesCache::currentActivityChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KActivities::ActivitiesCache::serviceStatusChanged(Consumer::ServiceStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KActivities::ActivitiesCache::activityListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
